define(
//begin v1.x content
({
	"saveLabel": "บันทึก",
	"saveSettingLabelOn": "ตั้งช่วงเวลาบันทึกอัตโนมัติ...",
	"saveSettingLabelOff": "ปิดบันทึกอัตโนมัติ",
	"saveSettingdialogTitle": "บันทึกอัตโนมัติ",
	"saveSettingdialogDescription": "ระบุช่วงเวลาบันทึกอัตโนมัติ",
	"saveSettingdialogParamName": "ช่วงเวลาบันทึกอัตโนมัติ",
	"saveSettingdialogParamLabel": "นาที",
	"saveSettingdialogButtonOk": "ตั้งช่วงเวลา",
	"saveSettingdialogButtonCancel": "ยกเลิก",
	"saveMessageSuccess": "ถูกบันทึกเมื่อ ${0}",
	"saveMessageFail": "ล้มเหลวในการบันทึกเมื่อ ${0}"
})

//end v1.x content
);
